[Zope3-checkins] CVS: Zope3/src/zope/app/http - configure.zcml:1.3 traversal.py:1.2

Sidnei da Silva sidnei@x3ng.com.br
Sat, 29 Mar 2003 12:04:29 -0500


Update of /cvs-repository/Zope3/src/zope/app/http
In directory cvs.zope.org:/tmp/cvs-serv25288

Modified Files:
	configure.zcml traversal.py 
Log Message:
Adding exception handler for unauthorized http exception. Should omit WWW-Authenticate headers.

=== Zope3/src/zope/app/http/configure.zcml 1.2 => 1.3 ===
--- Zope3/src/zope/app/http/configure.zcml:1.2	Fri Feb 28 17:34:28 2003
+++ Zope3/src/zope/app/http/configure.zcml	Sat Mar 29 12:03:58 2003
@@ -49,4 +49,6 @@
   allowed_attributes="DELETE"
   />
 
+<include package=".exception" />
+
 </zopeConfigure>


=== Zope3/src/zope/app/http/traversal.py 1.1 => 1.2 ===
--- Zope3/src/zope/app/http/traversal.py:1.1	Fri Feb  7 10:59:37 2003
+++ Zope3/src/zope/app/http/traversal.py	Sat Mar 29 12:03:58 2003
@@ -47,8 +47,8 @@
         if request.getTraversalStack():
             raise NotFoundError(self.context, name, request)
 
-        # This should only happen for a PUT:
-        if request.method != 'PUT':
+        # This should only happen for a PUT or MKCOL:
+        if request.method not in  ['PUT', 'MKCOL']:
             raise NotFoundError(self.context, name, request)
 
         return NullResource(self.context, name)